==> haskell-monad-unlift-0.2.0-37-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-unlift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-unlift
version: 0.2.0
id: monad-unlift-0.2.0-4obT627eljA6yPMEn52mXW
key: monad-unlift-0.2.0-4obT627eljA6yPMEn52mXW
license: MIT
copyright: FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/monad-unlift
synopsis: Typeclasses for representing monad transformer unlifting
description:
    See README.md
category: Control
abi: 93aa493de403c7d17cbd4cc1f7da52c8
exposed: True
exposed-modules:
    Control.Monad.Trans.Unlift
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-unlift-0.2.0
hs-libraries: HSmonad-unlift-0.2.0-4obT627eljA6yPMEn52mXW
depends:
    base-4.11.1.0 monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI
    transformers-0.5.5.0
    transformers-base-0.4.5.2-8WC7bFFnNGCEYZMgQnFBlc
    constraints-0.10.1-LDWlj2y4ldD7xhipC96EBn
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI=1f75827c7503f69e21680c4f5fdd5ce1
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-8WC7bFFnNGCEYZMgQnFBlc=8d6025dec3e5dd700b855b90a1ac9ead
             constraints-0.10.1-LDWlj2y4ldD7xhipC96EBn=62376005a8bb043ab4b0624aa6a80047
haddock-interfaces: /usr/share/doc/haskell-monad-unlift/html/monad-unlift.haddock
haddock-html: /usr/share/doc/haskell-monad-unlift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-unlift-0.2.0-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-unlift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-unlift
version: 0.2.0
id: monad-unlift-0.2.0-4daTp8xdY5aC3PDXxENaX9
key: monad-unlift-0.2.0-4daTp8xdY5aC3PDXxENaX9
license: MIT
copyright: FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/monad-unlift
synopsis: Typeclasses for representing monad transformer unlifting
description:
    See README.md
category: Control
abi: c041d13d66f041db0c215142349ddd7e
exposed: True
exposed-modules:
    Control.Monad.Trans.Unlift
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-unlift-0.2.0
hs-libraries: HSmonad-unlift-0.2.0-4daTp8xdY5aC3PDXxENaX9
depends:
    base-4.11.1.0 monad-control-1.0.2.3-2M5i4nR3tZN58HK4Iovcf6
    transformers-0.5.5.0
    transformers-base-0.4.5.2-71OkzG0c7DN1mT5seqZVLg
    constraints-0.10.1-T7V00Rz9wsI0eIpJqSvMQ
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             monad-control-1.0.2.3-2M5i4nR3tZN58HK4Iovcf6=426b8f9fb13500fce88d5a07e4a185fc
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-71OkzG0c7DN1mT5seqZVLg=1413ad31d00a6763c36b63397e5c2714
             constraints-0.10.1-T7V00Rz9wsI0eIpJqSvMQ=b4d4e1f85158959468cd8a9698f35df2
haddock-interfaces: /usr/share/doc/haskell-monad-unlift/html/monad-unlift.haddock
haddock-html: /usr/share/doc/haskell-monad-unlift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
